@@ -100,7 +100,7 @@ static PyObject *settingsTypeCoercion(const QVariant &out, PyTypeObject *typeObj
         // Convert any string, etc, to a list of 1 element
         if (auto *primitiveValue = convertToPrimitiveType(out, out.typeId())) {
             PyObject *list = PyList_New(1);
-            PyList_SET_ITEM(list, 0, primitiveValue);
+            PyList_SetItem(list, 0, primitiveValue);
             return list;
         }
 
@@ -113,7 +113,7 @@ static PyObject *settingsTypeCoercion(const QVariant &out, PyTypeObject *typeObj
         PyObject *list = PyList_New(valuesSize);
         for (Py_ssize_t i = 0; i < valuesSize; ++i) {
             PyObject *item = PyUnicode_FromString(valuesList.at(i).constData());
-            PyList_SET_ITEM(list, i, item);
+            PyList_SetItem(list, i, item);
         }
         return list;
     }
@@ -231,8 +231,8 @@ static QVariant QVariant_convertToVariantMap(PyObject *map)
     Shiboken::AutoDecRef keys(PyDict_Keys(map));
     if (!QVariant_isStringList(keys))
         return {};
-    PyObject *key;
-    PyObject *value;
+    PyObject *key{};
+    PyObject *value{};
     QMap<QString,QVariant> ret;
     while (PyDict_Next(map, &pos, &key, &value)) {
         QString cppKey = %CONVERTTOCPP[QString](key);
@@ -259,9 +259,9 @@ static QVariant QVariant_convertToVariantList(PyObject *list)
 
     QList<QVariant> lst;
     Shiboken::AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
-    const Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
+    const Py_ssize_t size = PySequence_Size(fast.object());
     for (Py_ssize_t i = 0; i < size; ++i) {
-        PyObject *pyItem = PySequence_Fast_GET_ITEM(fast.object(), i);
+        Shiboken::AutoDecRef pyItem(PySequence_GetItem(fast.object(), i));
         QVariant item = %CONVERTTOCPP[QVariant](pyItem);
         lst.append(item);
     }
@@ -322,7 +322,7 @@ QByteArray uncompressed = %FUNCTION_NAME(ptr, %2);
 QList<QByteArray> version = QByteArray(qVersion()).split('.');
 PyObject *pyQtVersion = PyTuple_New(3);
 for (int i = 0; i < 3; ++i)
-    PyTuple_SET_ITEM(pyQtVersion, i, PyLong_FromLong(version[i].toInt()));
+    PyTuple_SetItem(pyQtVersion, i, PyLong_FromLong(version[i].toInt()));
 PyModule_AddObject(module, "__version_info__", pyQtVersion);
 PyModule_AddStringConstant(module, "__version__", qVersion());
 // @snippet qt-version
@@ -374,7 +374,7 @@ PyModule_AddStringConstant(module, "__version__", qVersion());
 // @snippet qobject-connect-6
 
 // @snippet qobject-emit
-%RETURN_TYPE %0 = PySide::SignalManager::instance().emitSignal(%CPPSELF, %1, %PYARG_2);
+%RETURN_TYPE %0 = PySide::SignalManager::emitSignal(%CPPSELF, %1, %PYARG_2);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qobject-emit
 
@@ -424,7 +424,6 @@ Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK
 
 PySide::registerInternalQtConf();
 PySide::init(module);
-Py_AtExit(QtCoreModuleExit);
 // @snippet qt-pysideinit
 
 // @snippet qt-messagehandler
@@ -434,17 +433,18 @@ static PyObject *qtmsghandler = nullptr;
 static void msgHandlerCallback(QtMsgType type, const QMessageLogContext &ctx, const QString &msg)
 {
     Shiboken::GilState state;
+    PyObject *excType{};
+    PyObject *excValue{};
+    PyObject *excTraceback{};
+    PyErr_Fetch(&excType, &excValue, &excTraceback);
     Shiboken::AutoDecRef arglist(PyTuple_New(3));
-    PyTuple_SET_ITEM(arglist, 0, %CONVERTTOPYTHON[QtMsgType](type));
-    PyTuple_SET_ITEM(arglist, 1, %CONVERTTOPYTHON[QMessageLogContext &](ctx));
+    PyTuple_SetItem(arglist, 0, %CONVERTTOPYTHON[QtMsgType](type));
+    PyTuple_SetItem(arglist, 1, %CONVERTTOPYTHON[QMessageLogContext &](ctx));
     QByteArray array = msg.toUtf8();  // Python handler requires UTF-8
     const char *data = array.constData();
-    PyTuple_SET_ITEM(arglist, 2, %CONVERTTOPYTHON[const char *](data));
+    PyTuple_SetItem(arglist, 2, %CONVERTTOPYTHON[const char *](data));
     Shiboken::AutoDecRef ret(PyObject_CallObject(qtmsghandler, arglist));
-}
-static void QtCoreModuleExit()
-{
-    PySide::SignalManager::instance().clear();
+    PyErr_Restore(excType, excValue, excTraceback);
 }
 // @snippet qt-messagehandler
 
@@ -479,8 +479,8 @@ namespace PySide {
 QPointF p;
 %RETURN_TYPE retval = %CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, &p);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[QPointF](p));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[QPointF](p));
 // @snippet qlinef-intersect
 
 // @snippet qresource-data
@@ -503,23 +503,26 @@ if (!PyDateTimeAPI)
 int year, month, day;
 %CPPSELF.%FUNCTION_NAME(&year, &month, &day);
 %PYARG_0 = PyTuple_New(3);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[int](year));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[int](month));
-PyTuple_SET_ITEM(%PYARG_0, 2, %CONVERTTOPYTHON[int](day));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[int](year));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[int](month));
+PyTuple_SetItem(%PYARG_0, 2, %CONVERTTOPYTHON[int](day));
 // @snippet qdate-getdate
 
 // @snippet qdate-weeknumber
 int yearNumber;
 int week = %CPPSELF.%FUNCTION_NAME(&yearNumber);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[int](week));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[int](yearNumber));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[int](week));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[int](yearNumber));
 // @snippet qdate-weeknumber
 
 // @snippet qdatetime-1
 QDate date(%1, %2, %3);
 QTime time(%4, %5, %6, %7);
-%0 = new %TYPE(date, time, Qt::TimeSpec(%8));
+%0 = new %TYPE(date, time,
+               Qt::TimeSpec(%8) == Qt::UTC
+               ? QTimeZone(QTimeZone::UTC) : QTimeZone(QTimeZone::LocalTime));
+Shiboken::Warnings::warnDeprecated("QDateTime", "QDateTime(..., Qt::TimeSpec spec)");
 // @snippet qdatetime-1
 
 // @snippet qdatetime-2
@@ -531,7 +534,9 @@ QTime time(%4, %5, %6);
 // @snippet qdatetime-3
 QDate date(%1, %2, %3);
 QTime time(%4, %5, %6, %7);
-%0 = new %TYPE(date, time, %8);
+%0 = new %TYPE(date, time,
+               %8 == Qt::UTC ? QTimeZone(QTimeZone::UTC) : QTimeZone(QTimeZone::LocalTime));
+Shiboken::Warnings::warnDeprecated("QDateTime", "QDateTime(..., Qt::TimeSpec spec)");
 // @snippet qdatetime-3
 
 // @snippet qdatetime-topython
@@ -553,9 +558,10 @@ return %CPPSELF.size();
 // @snippet qbitarray-len
 
 // @snippet qbitarray-getitem
-if (_i < 0 || _i >= %CPPSELF.size()) {
-    PyErr_SetString(PyExc_IndexError, "index out of bounds");
-    return 0;
+const Py_ssize_t size = %CPPSELF.size();
+if (_i < 0 || _i >= size) {
+    Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
+    return nullptr;
 }
 bool ret = %CPPSELF.at(_i);
 return %CONVERTTOPYTHON[bool](ret);
@@ -569,6 +575,26 @@ Py_XDECREF(result);
 return !result ? -1 : 0;
 // @snippet qbitarray-setitem
 
+// @snippet qmodelroledata-setdata
+// Call template <typename T> void QModelRoleData::setData(T &&value)
+%CPPSELF.%FUNCTION_NAME(%1);
+// @snippet qmodelroledata-setdata
+
+// @snippet qmodelroledataspan-len
+return %CPPSELF.size();
+// @snippet qmodelroledataspan-len
+
+// @snippet qmodelroledataspan-getitem
+const Py_ssize_t size = %CPPSELF.size();
+if (_i < 0 || _i >= size) {
+    Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
+    return nullptr;
+}
+// Return a pointer to allow for modification using  QModelRoleData::setData()
+QModelRoleData *item = &((*%CPPSELF)[_i]);
+return %CONVERTTOPYTHON[QModelRoleData *](item);
+// @snippet qmodelroledataspan-getitem
+
 // @snippet default-enter
 Py_INCREF(%PYSELF);
 pyResult = %PYSELF;
@@ -630,8 +656,11 @@ if (ret == nullptr) {
 // @snippet qbytearray-mgetitem
 if (PyIndex_Check(_key)) {
     const Py_ssize_t _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
-    if (_i < 0 || _i >= %CPPSELF.size())
-        return PyErr_Format(PyExc_IndexError, "index out of bounds");
+    const Py_ssize_t size = %CPPSELF.size();
+    if (_i < 0 || _i >= size) {
+        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
+        return nullptr;
+    }
     char res[2] = {%CPPSELF.at(_i), '\0'};
     return PyBytes_FromStringAndSize(res, 1);
 }
@@ -641,9 +670,12 @@ if (PySlice_Check(_key) == 0)
                  "list indices must be integers or slices, not %.200s",
                  Py_TYPE(_key)->tp_name);
 
-Py_ssize_t start, stop, step, slicelength;
-if (PySlice_GetIndicesEx(_key, %CPPSELF.size(), &start, &stop, &step, &slicelength) < 0)
+Py_ssize_t start{};
+Py_ssize_t stop{};
+Py_ssize_t step{};
+if (PySlice_Unpack(_key, &start, &stop, &step) < 0)
     return nullptr;
+Py_ssize_t slicelength = PySlice_AdjustIndices(%CPPSELF.size(), &start, &stop, step);
 
 QByteArray ba;
 if (slicelength <= 0)
@@ -716,9 +748,12 @@ if (PySlice_Check(_key) == 0) {
     return -1;
 }
 
-Py_ssize_t start, stop, step, slicelength;
-if (PySlice_GetIndicesEx(_key, %CPPSELF.size(), &start, &stop, &step, &slicelength) < 0)
+Py_ssize_t start{};
+Py_ssize_t stop{};
+Py_ssize_t step{};
+if (PySlice_Unpack(_key, &start, &stop, &step) < 0)
     return -1;
+const Py_ssize_t slicelength = PySlice_AdjustIndices(%CPPSELF.size(), &start, &stop, step);
 
 // The parameter candidates are: bytes/str, bytearray, QByteArray itself.
 // Not supported are iterables containing ints between 0~255
@@ -812,7 +847,7 @@ static PyBufferProcs SbkQByteArrayBufferProc = {
 // @snippet qbytearray-bufferprotocol
 
 // @snippet qbytearray-operatorplus-1
-QByteArray ba = QByteArray(PyBytes_AS_STRING(%PYARG_1), PyBytes_GET_SIZE(%PYARG_1)) + *%CPPSELF;
+QByteArray ba = QByteArray(PyBytes_AsString(%PYARG_1), PyBytes_Size(%PYARG_1)) + *%CPPSELF;
 %PYARG_0 = %CONVERTTOPYTHON[QByteArray](ba);
 // @snippet qbytearray-operatorplus-1
 
@@ -833,7 +868,7 @@ QByteArray ba = *%CPPSELF + QByteArray(PyByteArray_AsString(%PYARG_1), PyByteArr
 // @snippet qbytearray-operatorequalequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF == ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -842,7 +877,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatornotequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF != ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -851,7 +886,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorgreater
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF > ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -860,7 +895,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorgreaterequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF >= ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -869,7 +904,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorlower
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF < ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -878,7 +913,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorlowerequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF <= ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -899,7 +934,7 @@ Py_DECREF(aux);
 // @snippet qbytearray-2
 
 // @snippet qbytearray-3
-%0 = new QByteArray(PyBytes_AS_STRING(%PYARG_1), PyBytes_GET_SIZE(%PYARG_1));
+%0 = new QByteArray(PyBytes_AsString(%PYARG_1), PyBytes_Size(%PYARG_1));
 // @snippet qbytearray-3
 
 // @snippet qbytearray-py3
@@ -924,15 +959,16 @@ return %CPPSELF.size();
 // @snippet qbytearray-len
 
 // @snippet qbytearray-getitem
-if (_i < 0 || _i >= %CPPSELF.size()) {
-    PyErr_SetString(PyExc_IndexError, "index out of bounds");
-    return 0;
-} else {
-    char res[2];
-    res[0] = %CPPSELF.at(_i);
-    res[1] = 0;
-    return PyBytes_FromStringAndSize(res, 1);
+const Py_ssize_t size = %CPPSELF.size();
+if (_i < 0 || _i >= size) {
+    Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
+    return nullptr;
 }
+
+char res[2];
+res[0] = %CPPSELF.at(_i);
+res[1] = 0;
+return PyBytes_FromStringAndSize(res, 1);
 // @snippet qbytearray-getitem
 
 // @snippet qbytearray-setitem
@@ -1061,25 +1097,8 @@ if (msec == 0) {
 
     QTimer * timer = %CONVERTTOCPP[QTimer *](pyTimer);
     timer->setSingleShot(true);
-
-    if (PyObject_TypeCheck(%2, PySideSignalInstance_TypeF())) {
-        PySideSignalInstance *signalInstance = reinterpret_cast<PySideSignalInstance *>(%2);
-        Shiboken::AutoDecRef signalSignature(Shiboken::String::fromFormat("2%s", PySide::Signal::getSignature(signalInstance)));
-        Shiboken::AutoDecRef result(
-            PyObject_CallMethod(pyTimer, "connect", "OsOO",
-                                pyTimer,
-                                SIGNAL(timeout()),
-                                PySide::Signal::getObject(signalInstance),
-                                signalSignature.object())
-        );
-    } else {
-        Shiboken::AutoDecRef result(
-            PyObject_CallMethod(pyTimer, "connect", "OsO",
-                                pyTimer,
-                                SIGNAL(timeout()),
-                                %PYARG_2)
-        );
-    }
+    if (!PySide::callConnect(pyTimer, SIGNAL(timeout()), %PYARG_2))
+        return nullptr;
 
     timer->connect(timer, &QTimer::timeout, timer, &QObject::deleteLater, Qt::DirectConnection);
     Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(pyTimer));
@@ -1133,8 +1152,8 @@ if (msec == 0) {
 qint64 pid;
 %RETURN_TYPE retval = %TYPE::%FUNCTION_NAME(%1, %2, %3, &pid);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[qint64](pid));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[qint64](pid));
 // @snippet qprocess-startdetached
 
 // @snippet qcoreapplication-init
@@ -1142,7 +1161,7 @@ static void QCoreApplicationConstructor(PyObject *self, PyObject *pyargv, QCoreA
 {
     static int argc;
     static char **argv;
-    PyObject *stringlist = PyTuple_GET_ITEM(pyargv, 0);
+    PyObject *stringlist = PyTuple_GetItem(pyargv, 0);
     if (Shiboken::listToArgcArgv(stringlist, &argc, &argv, "PySideApp")) {
         *cptr = new QCoreApplicationWrapper(argc, argv);
         Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(self));
@@ -1230,7 +1249,7 @@ PySideEasingCurveFunctor::init();
 // @snippet qeasingcurve
 
 // @snippet qeasingcurve-setcustomtype
-QEasingCurve::EasingFunction func = PySideEasingCurveFunctor::createCustomFuntion(%PYSELF, %PYARG_1);
+QEasingCurve::EasingFunction func = PySideEasingCurveFunctor::createCustomFunction(%PYSELF, %PYARG_1);
 if (func)
     %CPPSELF.%FUNCTION_NAME(func);
 // @snippet qeasingcurve-setcustomtype
@@ -1265,26 +1284,36 @@ QT_END_NAMESPACE
 // @snippet qt-registerresourcedata
 
 // @snippet qt-qregisterresourcedata
-%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_2)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_3)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_4)));
+%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_2)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_3)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_4)));
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qt-qregisterresourcedata
 
 // @snippet qt-qunregisterresourcedata
-%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_2)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_3)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_4)));
+%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_2)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_3)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_4)));
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qt-qunregisterresourcedata
 
-// @snippet use-stream-for-format-security
-// Uses the stream version for security reasons
-// see gcc man page at -Wformat-security
+// @snippet qdebug-format-string
 Py_BEGIN_ALLOW_THREADS
-%FUNCTION_NAME() << %1;
+%FUNCTION_NAME("%s", %1); // Uses placeholder for security reasons
 Py_END_ALLOW_THREADS
-// @snippet use-stream-for-format-security
+// @snippet qdebug-format-string
+
+// @snippet qmessagelogger-format-string
+Py_BEGIN_ALLOW_THREADS
+%CPPSELF->%FUNCTION_NAME("%s", %1); // Uses placeholder for security reasons
+Py_END_ALLOW_THREADS
+// @snippet qmessagelogger-format-string
+
+// @snippet qmessagelogger-logcategory-format-string
+Py_BEGIN_ALLOW_THREADS
+%CPPSELF->%FUNCTION_NAME(%1, "%s", %2); // Uses placeholder for security reasons
+Py_END_ALLOW_THREADS
+// @snippet qmessagelogger-logcategory-format-string
 
 // @snippet qresource-registerResource
  auto ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(%PYARG_1));
@@ -1318,8 +1347,8 @@ QString &res = *%0;
 // @snippet return-readData
 %RETURN_TYPE %0 = 0;
 if (PyBytes_Check(%PYARG_0)) {
-    %0 = PyBytes_GET_SIZE(%PYARG_0.object());
-    memcpy(%1, PyBytes_AS_STRING(%PYARG_0.object()), %0);
+    %0 = PyBytes_Size(%PYARG_0.object());
+    memcpy(%1, PyBytes_AsString(%PYARG_0.object()), %0);
 } else if (Shiboken::String::check(%PYARG_0.object())) {
     %0 = Shiboken::String::len(%PYARG_0.object());
     memcpy(%1, Shiboken::String::toCString(%PYARG_0.object()), %0);
@@ -1351,8 +1380,8 @@ Py_END_ALLOW_THREADS
     if (!atexit.isNull() && !regFunc.isNull()){
         PyObject *shutDownFunc = PyObject_GetAttrString(module, "__moduleShutdown");
         Shiboken::AutoDecRef args(PyTuple_New(1));
-        PyTuple_SET_ITEM(args, 0, shutDownFunc);
-        Shiboken::AutoDecRef retval(PyObject_Call(regFunc, args, 0));
+        PyTuple_SetItem(args, 0, shutDownFunc);
+        Shiboken::AutoDecRef retval(PyObject_Call(regFunc, args, nullptr));
         Q_ASSERT(!retval.isNull());
     }
 }
@@ -1580,7 +1609,7 @@ int usec = PyDateTime_TIME_GET_MICROSECOND(%in);
 // @snippet conversion-qtime-pytime
 
 // @snippet conversion-qbytearray-pybytes
-%out = %OUTTYPE(PyBytes_AS_STRING(%in), PyBytes_GET_SIZE(%in));
+%out = %OUTTYPE(PyBytes_AsString(%in), PyBytes_Size(%in));
 // @snippet conversion-qbytearray-pybytes
 
 // @snippet conversion-qbytearray-pybytearray
@@ -1603,6 +1632,14 @@ return PyBool_FromLong((bool)%in);
 return PyBytes_FromStringAndSize(%in.constData(), %in.size());
 // @snippet return-pybytes
 
+// @snippet chrono-to-pylong
+return PyLong_FromLong(%in.count());
+// @snippet chrono-to-pylong
+
+// @snippet pylong-to-chrono
+%out = %OUTTYPE(PyLong_AsLongLong(%in));
+// @snippet pylong-to-chrono
+
 // @snippet return-pylong
 return PyLong_FromLong(%in);
 // @snippet return-pylong
@@ -1692,7 +1729,7 @@ if (converterO.has_value())
     return converterO.value().toPython(cppInRef.data());
 
 PyErr_Format(PyExc_RuntimeError, "Can't find converter for '%s'.", %in.typeName());
-return 0;
+return nullptr;
 // @snippet return-qvariant
 
 // @snippet return-qjsonobject
@@ -1732,18 +1769,51 @@ pthread_cleanup_pop(0);
 #endif
 // @snippet qthread_pthread_cleanup_uninstall
 
-// @snippet qlibraryinfo_build
-auto oldResult = pyResult;
-const auto version = _PepRuntimeVersion();
-pyResult = PyUnicode_FromFormat(
-#ifdef Py_LIMITED_API
-                                "%U [Python limited API %d.%d.%d]",
+// @snippet qlibraryinfo_python_build
+
+// For versions with one byte per digit.
+static QByteArray versionString(long version)
+{
+    return QByteArray::number((version >> 16) & 0xFF)
+           + '.' + QByteArray::number((version >> 8) & 0xFF)
+           + '.' + QByteArray::number(version & 0xFF);
+}
+
+static QByteArray pythonBuild()
+{
+    using namespace Qt::StringLiterals;
+
+#ifdef PYPY_VERSION
+    QByteArray result = "PyPy " PYPY_VERSION
 #else
-                                "%U [Python %d.%d.%d]",
+    QByteArray result = "Python"
 #endif
-                                oldResult, (version >> 16) & 0xFF,
-                                (version >> 8) & 0xFF, version & 0xFF);
-Py_DECREF(oldResult);
+#ifdef Py_LIMITED_API
+    " limited API"
+#endif
+#ifdef Py_GIL_DISABLED
+    " free threaded"
+#endif
+        ;
+    result += ' ';
+
+    const auto runTimeVersion = _PepRuntimeVersion();
+    const auto runTimeVersionB = versionString(runTimeVersion);
+    constexpr long buildVersion = PY_VERSION_HEX >> 8;
+    if (runTimeVersion == buildVersion) {
+        result += runTimeVersionB;
+    } else {
+        result += "run time: "_ba + runTimeVersionB + " built: "_ba
+                  + versionString(buildVersion);
+    }
+    return result;
+}
+// @snippet qlibraryinfo_python_build
+
+// @snippet qlibraryinfo_build
+QByteArray %0 = %CPPSELF.%FUNCTION_NAME();
+%0 += " [" + pythonBuild() + ']';
+%PYARG_0 = PyUnicode_FromString(%0.constData());
 // @snippet qlibraryinfo_build
 
 // @snippet qsharedmemory_data_readonly
@@ -1803,13 +1873,6 @@ if (dataChar == nullptr) {
 }
 // @snippet qdatastream-read-bytes
 
-// @snippet qloggingcategory_to_cpp
-// PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
-    QLoggingCategory *category{nullptr};
-    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type,
-    pyArgs[0], &(category));
-// @snippet qloggingcategory_to_cpp
-
 // Q_ARG()-equivalent
 // @snippet q_arg
 const QArgData qArgData = qArgDataFromPyType(%1);
@@ -2071,12 +2134,12 @@ if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
 
 bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));
 
-auto callback = [callable, count, arg_qpermission](const QPermission &permission) -> void
+auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
 {
     Shiboken::GilState state;
     if (arg_qpermission) {
         Shiboken::AutoDecRef arglist(PyTuple_New(1));
-        PyTuple_SET_ITEM(arglist.object(), 0, %CONVERTTOPYTHON[QPermission](permission));
+        PyTuple_SetItem(arglist.object(), 0, %CONVERTTOPYTHON[QPermission](permission));
         Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
     } else {
         Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
@@ -2095,9 +2158,9 @@ qint64 pid{};
 QString hostname, appname;
 %CPPSELF.%FUNCTION_NAME(&pid, &hostname, &appname);
 %PYARG_0 = PyTuple_New(3);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[qint64](pid));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[QString](hostname));
-PyTuple_SET_ITEM(%PYARG_0, 2, %CONVERTTOPYTHON[QString](appname));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[qint64](pid));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[QString](hostname));
+PyTuple_SetItem(%PYARG_0, 2, %CONVERTTOPYTHON[QString](appname));
 // @snippet qlockfile-getlockinfo
 
 // @snippet darwin_permission_plugin
@@ -2115,7 +2178,9 @@ Q_IMPORT_PLUGIN(QDarwinCalendarPermissionPlugin)
 // @snippet qt-modifier
 PyObject *_inputDict = PyDict_New();
 // Note: The builtins line is no longer needed since Python 3.10. Undocumented!
-PyDict_SetItemString(_inputDict, "__builtins__", PyEval_GetBuiltins());
+Shiboken::AutoDecRef builtins(PepEval_GetFrameBuiltins());
+PyDict_SetItemString(_inputDict, "__builtins__", builtins.object());
+builtins.reset(nullptr);
 PyDict_SetItemString(_inputDict, "QtCore", module);
 PyDict_SetItemString(_inputDict, "Qt", reinterpret_cast<PyObject *>(pyType));
 // Explicitly not dereferencing the result.
@@ -2148,3 +2213,41 @@ PyRun_String(R"PY(if True:
 
 )PY", Py_file_input, _inputDict, _inputDict);
 // @snippet qt-modifier
+
+// @snippet qdirlisting-iter
+auto result = QtCoreHelper::QDirListingIterator(*%CPPSELF);
+%PYARG_0 = %CONVERTTOPYTHON[QtCoreHelper::QDirListingIterator](result);
+// @snippet qdirlisting-iter
+
+// @snippet qdirlistingiterator-next
+if (%CPPSELF.next()) {
+    Py_INCREF(%PYSELF);
+    %PYARG_0 = %PYSELF;
+}
+// @snippet qdirlistingiterator-next
+
+// @snippet qdirlisting-direntry-repr
+QByteArray result = '<' + QByteArray(Py_TYPE(%PYSELF)->tp_name)
+                    + " object at 0x"
+                    + QByteArray::number(quintptr(%PYSELF), 16) + " (\""
+                    + %CPPSELF.absoluteFilePath().toUtf8() + "\")>";
+%PYARG_0 = Shiboken::String::fromCString(result.constData());
+// @snippet qdirlisting-direntry-repr
+
+// @snippet return-native-eventfilter-conversion
+%RETURN_TYPE %out = false;
+if (PySequence_Check(%PYARG_0) != 0 && PySequence_Size(%PYARG_0) == 2) {
+    Shiboken::AutoDecRef pyItem(PySequence_GetItem(%PYARG_0, 0));
+    %out = %CONVERTTOCPP[bool](pyItem);
+    if (result) {
+        Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
+        *result = %CONVERTTOCPP[qintptr](pyResultItem);
+    }
+}
+// @snippet return-native-eventfilter-conversion
+
+// @snippet return-native-eventfilter
+%PYARG_0 = PyTuple_New(2);
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](%0));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[qintptr](*result_out));
+// @snippet return-native-eventfilter
