@@ -9,16 +9,18 @@
 #include "pysideproperty_p.h"
 #include "pysideslot_p.h"
 #include "pysideqenum.h"
-#include "pyside_p.h"
 #include "pysidestaticstrings.h"
 
-#include <shiboken.h>
+#include <autodecref.h>
+#include <gilstate.h>
+#include <sbkstaticstrings.h>
+#include <sbkstring.h>
 
-#include <QtCore/QByteArray>
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
-#include <QtCore/QTextStream>
-#include <QtCore/QList>
+#include <QtCore/qbytearray.h>
+#include <QtCore/qobject.h>
+#include <QtCore/qstringlist.h>
+#include <QtCore/qtextstream.h>
+#include <QtCore/qlist.h>
 #include <private/qmetaobjectbuilder_p.h>
 
 #include <cstring>
@@ -53,7 +55,8 @@ public:
                       const QByteArray &signature) const;
     int indexOfProperty(const QByteArray &name) const;
     int addSlot(const QByteArray &signature);
-    int addSlot(const QByteArray &signature, const QByteArray &type);
+    int addSlot(const QByteArray &signature, const QByteArray &type,
+                const QByteArray &tag = {});
     int addSignal(const QByteArray &signature);
     void removeMethod(QMetaMethod::MethodType mtype, int index);
     int getPropertyNotifyId(PySideProperty *property) const;
@@ -100,12 +103,10 @@ MetaObjectBuilder::MetaObjectBuilder(PyTypeObject *type, const QMetaObject *meta
     : m_d(new MetaObjectBuilderPrivate)
 {
     m_d->m_baseObject = metaObject;
-    const char *className = type->tp_name;
-    if (const char *lastDot = strrchr(type->tp_name, '.'))
-        className = lastDot + 1;
+    const char *className = PepType_GetNameStr(type);
     // Different names indicate a Python class inheriting a Qt class.
     // Parse the type.
-    if (strcmp(className, metaObject->className()) != 0) {
+    if (std::strcmp(className, metaObject->className()) != 0) {
         m_d->m_builder = new QMetaObjectBuilder();
         m_d->m_builder->setClassName(className);
         m_d->m_builder->setSuperClass(metaObject);
@@ -115,7 +116,7 @@ MetaObjectBuilder::MetaObjectBuilder(PyTypeObject *type, const QMetaObject *meta
 
 MetaObjectBuilder::~MetaObjectBuilder()
 {
-    for (auto *metaObject : m_d->m_cachedMetaObjects)
+    for (const auto *metaObject : m_d->m_cachedMetaObjects)
         free(const_cast<QMetaObject*>(metaObject));
     delete m_d->m_builder;
     delete m_d;
@@ -205,13 +206,14 @@ int MetaObjectBuilderPrivate::addSlot(const QByteArray &signature)
         + ensureBuilder()->addSlot(signature).index();
 }
 
-int MetaObjectBuilder::addSlot(const char *signature)
+int MetaObjectBuilder::addSlot(const QByteArray &signature)
 {
     return m_d->addSlot(signature);
 }
 
 int MetaObjectBuilderPrivate::addSlot(const QByteArray &signature,
-                                      const QByteArray &type)
+                                      const QByteArray &type,
+                                      const QByteArray &tag)
 {
     if (!checkMethodSignature(signature))
         return -1;
@@ -219,10 +221,12 @@ int MetaObjectBuilderPrivate::addSlot(const QByteArray &signature,
     QMetaMethodBuilder methodBuilder = ensureBuilder()->addSlot(signature);
     if (!type.isEmpty() && type != "void"_ba)
         methodBuilder.setReturnType(type);
+    if (!tag.isEmpty())
+        methodBuilder.setTag(tag);
     return m_baseObject->methodCount() + methodBuilder.index();
 }
 
-int MetaObjectBuilder::addSlot(const char *signature, const char *type)
+int MetaObjectBuilder::addSlot(const QByteArray &signature, const QByteArray &type)
 {
     return m_d->addSlot(signature, type);
 }
@@ -236,7 +240,7 @@ int MetaObjectBuilderPrivate::addSignal(const QByteArray &signature)
         + ensureBuilder()->addSignal(signature).index();
 }
 
-int MetaObjectBuilder::addSignal(const char *signature)
+int MetaObjectBuilder::addSignal(const QByteArray &signature)
 {
     return m_d->addSignal(signature);
 }
@@ -245,7 +249,7 @@ void MetaObjectBuilderPrivate::removeMethod(QMetaMethod::MethodType mtype,
                                             int index)
 {
     index -= m_baseObject->methodCount();
-    auto builder = ensureBuilder();
+    auto *builder = ensureBuilder();
     Q_ASSERT(index >= 0 && index < builder->methodCount());
     switch (mtype) {
     case QMetaMethod::Constructor:
@@ -273,6 +277,15 @@ int MetaObjectBuilderPrivate::getPropertyNotifyId(PySideProperty *property) cons
     return notifyId;
 }
 
+static QByteArray msgInvalidPropertyType(const QByteArray &className,
+                                         const QByteArray &propertyName,
+                                         const QByteArray &propertyType)
+{
+    return "QMetaObjectBuilder: Failed to add property \""_ba + propertyName
+           + "\" to \""_ba + className + "\": Invalid property type \""
+           + propertyType + "\"."_ba;
+}
+
 QMetaPropertyBuilder
     MetaObjectBuilderPrivate::createProperty(PySideProperty *property,
                                              const QByteArray &propertyName)
@@ -298,8 +311,13 @@ QMetaPropertyBuilder
             }
         }
     }
-    return builder->addProperty(propertyName, property->d->typeName,
-                                propertyNotifyId);
+    const auto metaType = QMetaType::fromName(property->d->typeName);
+    if (!metaType.isValid()) {
+        const auto &msg = msgInvalidPropertyType(m_builder->className(), propertyName,
+                                                 property->d->typeName);
+         PyErr_WarnEx(PyExc_RuntimeWarning, msg.constData(), 0);
+    }
+    return builder->addProperty(propertyName, property->d->typeName, metaType, propertyNotifyId);
 }
 
 int MetaObjectBuilderPrivate::addProperty(const QByteArray &propertyName,
@@ -347,7 +365,7 @@ void MetaObjectBuilder::addInfo(const char *key, const char *value)
 
 void MetaObjectBuilderPrivate::addInfo(const QMap<QByteArray, QByteArray> &info)
 {
-    auto builder = ensureBuilder();
+    auto *builder = ensureBuilder();
     for (auto i = info.constBegin(), end = info.constEnd(); i != end; ++i)
         builder->addClassInfo(i.key(), i.value());
     m_dirty = true;
@@ -367,7 +385,7 @@ void MetaObjectBuilder::addEnumerator(const char *name, bool flag, bool scoped,
 void MetaObjectBuilderPrivate::addEnumerator(const char *name, bool flag, bool scoped,
                                              const MetaObjectBuilder::EnumValues &entries)
 {
-    auto builder = ensureBuilder();
+    auto *builder = ensureBuilder();
     int have_already = builder->indexOfEnumerator(name);
     if (have_already >= 0)
         builder->removeEnumerator(have_already);
@@ -383,7 +401,7 @@ void MetaObjectBuilderPrivate::addEnumerator(const char *name, bool flag, bool s
 void MetaObjectBuilderPrivate::removeProperty(int index)
 {
     index -= m_baseObject->propertyCount();
-    auto builder = ensureBuilder();
+    auto *builder = ensureBuilder();
     Q_ASSERT(index >= 0 && index < builder->propertyCount());
     builder->removeProperty(index);
     m_dirty = true;
@@ -513,7 +531,7 @@ QString MetaObjectBuilder::formatMetaObject(const QMetaObject *metaObject)
     QTextStream str(&result);
     str << "PySide" << QT_VERSION_MAJOR << ".QtCore.QMetaObject(\""
         << metaObject->className() << '"';
-    if (auto *s = metaObject->superClass())
+    if (const auto *s = metaObject->superClass())
         str << " inherits \"" << s->className() << '"';
     str << ":\n";
 
@@ -563,18 +581,18 @@ void MetaObjectBuilderPrivate::parsePythonType(PyTypeObject *type)
     // This enforces registering of all signals and slots at type parsing time, and not later at
     // signal connection time, thus making sure no method indices change which would break
     // existing connections.
-    const PyObject *mro = type->tp_mro;
-    const Py_ssize_t basesCount = PyTuple_GET_SIZE(mro);
+    PyObject *mro = type->tp_mro;
+    const Py_ssize_t basesCount = PyTuple_Size(mro);
 
     std::vector<PyTypeObject *> basesToCheck;
     // Prepend the actual type that we are parsing.
-    basesToCheck.reserve(1u + basesCount);
+    basesToCheck.reserve(1U + basesCount);
     basesToCheck.push_back(type);
 
-    auto sbkObjTypeF = SbkObject_TypeF();
-    auto baseObjType = reinterpret_cast<PyTypeObject *>(&PyBaseObject_Type);
+    auto *sbkObjTypeF = SbkObject_TypeF();
+    auto *baseObjType = &PyBaseObject_Type;
     for (Py_ssize_t i = 0; i < basesCount; ++i) {
-        auto baseType = reinterpret_cast<PyTypeObject *>(PyTuple_GET_ITEM(mro, i));
+        auto *baseType = reinterpret_cast<PyTypeObject *>(PyTuple_GetItem(mro, i));
         if (baseType != sbkObjTypeF && baseType != baseObjType
             && !PySide::isQObjectDerived(baseType, false)) {
             basesToCheck.push_back(baseType);
@@ -630,7 +648,7 @@ void MetaObjectBuilderPrivate::parsePythonType(PyTypeObject *type)
                 const int index = m_baseObject->indexOfProperty(name);
                 if (index == -1)
                     addProperty(name, value);
-            } else if (Py_TYPE(value)->tp_call != nullptr) {
+            } else if (PepType_GetSlot(Py_TYPE(value), Py_tp_call) != nullptr) {
                 // PYSIDE-198: PyFunction_Check does not work with Nuitka.
                 // Register slots.
                 if (PyObject_HasAttr(value, slotAttrName)) {
@@ -638,7 +656,7 @@ void MetaObjectBuilderPrivate::parsePythonType(PyTypeObject *type)
                     const auto *entryList = PySide::Slot::dataListFromCapsule(capsule);
                     for (const auto &e : *entryList) {
                         if (m_baseObject->indexOfSlot(e.signature) == -1)
-                            addSlot(e.signature, e.resultType);
+                            addSlot(e.signature, e.resultType, e.tag);
                     }
                 }
             }
@@ -651,7 +669,7 @@ void MetaObjectBuilderPrivate::parsePythonType(PyTypeObject *type)
         AutoDecRef obName(PyObject_GetAttr(obEnumType, PyMagicName::name()));
         // Everything has been checked already in resolveDelayedQEnums.
         // Therefore, we don't need to error-check here again.
-        auto name = String::toCString(obName);
+        const auto *name = String::toCString(obName);
         AutoDecRef members(PyObject_GetAttr(obEnumType, PyMagicName::members()));
         AutoDecRef items(PyMapping_Items(members));
         Py_ssize_t nr_items = PySequence_Length(items);
@@ -662,7 +680,7 @@ void MetaObjectBuilderPrivate::parsePythonType(PyTypeObject *type)
             AutoDecRef key(PySequence_GetItem(item, 0));
             AutoDecRef member(PySequence_GetItem(item, 1));
             AutoDecRef value(PyObject_GetAttr(member, Shiboken::PyName::value()));
-            auto ckey = String::toCString(key);
+            const auto *ckey = String::toCString(key);
             auto ivalue = PyLong_AsSsize_t(value);
             entries.push_back(std::make_pair(ckey, int(ivalue)));
         }
