@@ -4,15 +4,19 @@
 #include "pysideqmllistproperty_p.h"
 #include "pysideqmlregistertype_p.h"
 
-#include <shiboken.h>
+#include <autodecref.h>
+#include <gilstate.h>
 #include <pep384ext.h>
+#include <sbkconverter.h>
 #include <signature.h>
+#include <sbkstring.h>
+#include <sbktypefactory.h>
 
 #include <pysideproperty.h>
 #include <pysideproperty_p.h>
 
-#include <QtCore/QObject>
-#include <QtQml/QQmlListProperty>
+#include <QtCore/qobject.h>
+#include <QtQml/qqmllist.h>
 
 // This is the user data we store in the property.
 class QmlListPropertyPrivate : public PySidePropertyPrivate
@@ -302,9 +306,10 @@ void initQtQmlListProperty(PyObject *module)
     // Register QQmlListProperty metatype for use in QML
     qRegisterMetaType<QQmlListProperty<QObject>>();
 
-    Py_INCREF(reinterpret_cast<PyObject *>(PropertyList_TypeF()));
-    PyModule_AddObject(module, PepType_GetNameStr(PropertyList_TypeF()),
-                       reinterpret_cast<PyObject *>(PropertyList_TypeF()));
+    auto *propertyListType = PropertyList_TypeF();
+    auto *obPropertyListType = reinterpret_cast<PyObject *>(propertyListType);
+    Py_INCREF(obPropertyListType);
+    PyModule_AddObject(module, PepType_GetNameStr(propertyListType), obPropertyListType);
 }
 
 } // namespace PySide::Qml
