@@ -12,21 +12,22 @@
 #include <optional>
 
 // shiboken
-#include <shiboken.h>
+#include <autodecref.h>
+#include <sbkconverter.h>
 #include <sbkstring.h>
+#include <sbktypefactory.h>
 
 // pyside
-#include <pyside.h>
 #include <pysideqobject.h>
 #include <pysideclassinfo.h>
 #include <pyside_p.h>
 
-#include <QtCore/QMutex>
-#include <QtCore/QTypeRevision>
+#include <QtCore/qmutex.h>
+#include <QtCore/qtyperevision.h>
 
 #include <QtQml/qqml.h>
-#include <QtQml/QJSValue>
-#include <QtQml/QQmlListProperty>
+#include <QtQml/qjsvalue.h>
+#include <QtQml/qqmllist.h>
 #include <private/qqmlmetatype_p.h>
 #include <private/qmetaobjectbuilder_p.h>
 
@@ -97,8 +98,11 @@ static inline bool isQmlParserStatus(const QMetaObject *o)
 
 static QByteArray getGlobalString(const char *name)
 {
-    PyObject *globalVar = PyDict_GetItemString(PyEval_GetGlobals(), name);
+    Shiboken::AutoDecRef globals(PepEval_GetFrameGlobals());
+    if (globals.isNull())
+        return {};
 
+    PyObject *globalVar = PyDict_GetItemString(globals, name);
     if (globalVar == nullptr || PyUnicode_Check(globalVar) == 0)
         return {};
 
@@ -108,8 +112,11 @@ static QByteArray getGlobalString(const char *name)
 
 static int getGlobalInt(const char *name)
 {
-    PyObject *globalVar = PyDict_GetItemString(PyEval_GetGlobals(), name);
+    Shiboken::AutoDecRef globals(PepEval_GetFrameGlobals());
+    if (globals.isNull())
+        return -1;
 
+    PyObject *globalVar = PyDict_GetItemString(globals, name);
     if (globalVar == nullptr || PyLong_Check(globalVar) == 0)
         return -1;
 
@@ -438,7 +445,7 @@ public:
     {
         Shiboken::GilState gil;
         Shiboken::AutoDecRef args(PyTuple_New(1));
-        PyTuple_SET_ITEM(args, 0,
+        PyTuple_SetItem(args, 0,
                          Shiboken::Conversions::pointerToPython(qQmlEngineType(), engine));
         PyObject *retVal = PyObject_CallObject(data()->callable, args);
         QObject *result = handleReturnValue(retVal);
@@ -540,7 +547,7 @@ static int qmlRegisterSingletonType(PyObject *pyObj, const ImportData &importDat
                 Shiboken::GilState gil;
                 AutoDecRef args(PyTuple_New(1));
 
-                PyTuple_SET_ITEM(args, 0, Conversions::pointerToPython(
+                PyTuple_SetItem(args, 0, Conversions::pointerToPython(
                                  qQmlEngineType(), engine));
 
                 AutoDecRef retVal(PyObject_CallObject(callback, args));
